<?php
set_time_limit(0);
/**
 * Plugin Name: Squeeze Blogs Upgrader
 * Plugin URI: http://blogprofitnetwork.com/
 * Description:
 * Version: 1.0.0
 * Author: Blog Profit Network
 * Author URI: http://blogprofitnetwork.com/
 *
 *
 *
 * Filename: sbp-upgrader.php
 * Created : Andy Christian S. Loyola <acl20032003@gmail.com> (http://AndysDesigns.Net)
 * Copyright 2017 - Andy Christian S. Loyola <acl20032003@gmail.com> (http://AndysDesigns.Net)
 *
 * Skype: andy_christian_loyola_
 * Yahoo: andz_christian
 * GTalk: acl20032003@gmail.com
 */
define ('_IN_MAIN_MODULE', 1);

/**
 * Change only the values under this variable
 *
 * @slugs           : temporary name for the plugin that we're gonna install
 * @install         : name of the folder when extracted + main file which holds the plugin information
 * @path            : url of the pro version ( zip format )
 * @delete_lite     : path of the lite version that needs to be deleted
 *
 * @upgrader_code   : url code to access the upgrader ( e.g. admin.php?page=code )
 * @upgrader_delete : path of the upgrader that needs to be deleted once the upgrade process is complete
 */
$plugin = array(
	'pro_slugs'         => 'squeezeblogs-pro-v2',
	'pro_install'       => 'squeezeblogs-pro-v2/sbp.php',
	'pro_path'          => 'http://motherhub.com/pro/squeezeblogs-pro-v2.zip',
	'pro_code'          => 'sbp',

	'lite_install'      => 'squeezeblogs-lite-v2/sbp.php',

	'upgrader_code'     => 'sbp-upgrader',
	'upgrader_install'  => 'squeezeblogs-upgrader/sbp-upgrader.php'
);



//* DO NOT EDIT CODES BELOW

//* 3rd party files
include_once (ABSPATH .'wp-admin/includes/file.php');


//* variables
$mcLiteToProUpgrader = new mcLiteToProUpgrader();

define ('MC_PRO_SLUGS', $plugin['pro_slugs']);
define ('MC_PRO_INSTALL', $plugin['pro_install']);
define ('MC_PRO_PATH', $plugin['pro_path']);
define ('MC_PRO_CODE', $plugin['pro_code']);

define ('MC_LITE_INSTALL', $plugin['lite_install']);

define ('MC_UPGRADER_CODE', $plugin['upgrader_code']);
define ('MC_UPGRADER_INSTALL', $plugin['upgrader_install']);

define ('MC_MENU_NAME', 'Lite To Pro');

define ('MC_PLUGIN_PATH', plugin_dir_path(__FILE__));
define ('MC_PLUGIN_DIR', plugin_dir_path(__DIR__));



//* admin menu
add_action('admin_menu', 'displayPageMcAdminMenu');
function displayPageMcAdminMenu() {
	add_menu_page(MC_MENU_NAME, MC_MENU_NAME, 9, MC_UPGRADER_CODE, 'displayPageMcUpgrader');
}

function displayPageMcUpgrader() {
    global $mcLiteToProUpgrader;

	$plugin = array(
		'slugs'     	=> MC_PRO_SLUGS,
		'install'   	=> MC_PRO_INSTALL,
		'path'      	=> MC_PRO_PATH,
		'code'      	=> MC_PRO_CODE,

		'delete_lite'	=> MC_LITE_INSTALL,
		'delete_install'=> MC_UPGRADER_INSTALL
	);

	$mcLiteToProUpgrader->install($plugin);



	echo '<div class="wrap">';
		echo '<h1>Installing PRO version - done. Enjoy :)</h1>';
	echo '</div>';
}
//* end of admin menu



//* upgrader class
class mcLiteToProUpgrader {
	var $fs;

	var $pluginDir;
	var $preserveZip;

	function __construct() {
		global $wp_filesystem;
		WP_Filesystem();

		$this->fs           = $wp_filesystem;
		$this->pluginDir    = ABSPATH .'wp-content/plugins/';
		$this->preserveZip  = false;
	}

	function dbug($str) {
		echo '<pre>';
			print_r ($str);
		echo '</pre>';
	}

    function downloadPlugin($url, $path) {
        $curl = @curl_init($url);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_TIMEOUT, 400);
        curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 0);
        $data = curl_exec($curl);
        curl_close($curl);

        if (!$this->fs->put_contents($path, $data, 0755)) {
            return false;
        }

        return true;
    }

	function unpackPlugin($target) {
		if (class_exists('ZipArchive')) {
			$zip    = new ZipArchive();
			$file   = $zip->open($target);
			if ($file === true) {
				$zip->extractTo($this->pluginDir);
				$zip->close();

				if ($this->preserveZip === false) {
					unlink($target);
				}

				return true;
			}
			else {
				return false;
			}
		}
		else {
			$dir = '';
			_unzip_file_pclzip($target, $this->pluginDir, $dir);
		}
	}

	function activatePlugin($installer) {
		$active = get_option('active_plugins');
		$plugin = plugin_basename($installer);

		if (!in_array($plugin, $active)) {
			$active[] = $plugin;
			sort($active);

			do_action('activate_plugin', trim($plugin));
			update_option('active_plugins', $active);

			do_action('activate_'. trim($plugin));
			do_action('activated_plugin', trim($plugin));
		}

		return null;
	}

	function deletePlugin($installer) {
		$active = get_option('active_plugins');
		$plugin = plugin_basename($installer);

		if (in_array($plugin, $active)) {
			deactivate_plugins(array($plugin));
			delete_plugins(array($plugin));

			return true;
		}
		return false;
	}

	function getPlugins($plugins) {
		if (0 != count($plugins)) {

			/**
			 * This happening in here
			 * # check + delete __MACOSX folder and make sure the $recursive value is set to true
			 * # download PRO version of the plugin
			 * # once downloaded, delete the lite version
			 * # unpack PRO version
			 * # install + activate
			 * # delete installer
			 * # redirect user to the PRO version
			 */

			if (is_dir($this->pluginDir .'__MACOSX')) {
				$this->fs->rmdir($this->pluginDir .'__MACOSX', true);
			}

			foreach ($plugins as $plugin) {
				$dloadUrl       = $plugin['path'];
				$dloadLocation  = $this->pluginDir . $plugin['name'] .'.zip';

				$this->deletePlugin($plugin['delete_lite']);
				$this->downloadPlugin($dloadUrl, $dloadLocation);
				$this->unpackPlugin($dloadLocation);
				$this->activatePlugin($plugin['install']);
			}

			$this->deletePlugin($plugin['delete_install']);

			//* use <meta /> to redirect instead of wp_redirect();
			$redirectUrl = admin_url('admin.php?page='. $plugin['code']);
			echo '<meta http-equiv="refresh" content="0;url='. $redirectUrl .'" />';
			exit();
		}
	}

	function install($data) {
		$plugins = array(
			array(
				'name'      	=> $data['slugs'],
				'install'   	=> $data['install'],
				'path'      	=> $data['path'],
				'code'      	=> $data['code'],

				'delete_lite'   => $data['delete_lite'],
				'delete_install'=> $data['delete_install']
			)
		);
		$this->getPlugins($plugins);
	}
}
